@@ -1,4 +1,9 @@
+use strictures 1;
 package Data::Collector::Info::CPU;
+BEGIN {
+  $Data::Collector::Info::CPU::VERSION = '0.07';
+}
+# ABSTRACT: Fetch machine CPU information
 
 use Moose;
 use MooseX::StrictConstructor;
@@ -33,28 +38,39 @@ sub count {
 
 sub mhz {
     my $self = shift;
-    return $1 if $self->raw_data =~ /^cpu MHz\s+\:\s+(.+)\n/m;
+    my $raw  = $self->raw_data || q{};
+    return $1 if $raw =~ /^cpu MHz\s+\:\s+(.+)\n/m;
 }
 
 sub model {
     my $self = shift;
-    return $1 if $self->raw_data =~ /^model name\s+\:\s+(.+)\n/m;
+    my $raw  = $self->raw_data || q{};
+    return $1 if $raw =~ /^model name\s+\:\s+(.+)\n/m;
 }
 
 sub flags {
     my $self = shift;
-    return $1 if $self->raw_data =~ /^flags\s+:\s+(.+)\n/m;
+    my $raw  = $self->raw_data || q{};
+    return $1 if $raw =~ /^flags\s+:\s+(.+)\n/m;
 }
 
 __PACKAGE__->meta->make_immutable;
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 Data::Collector::Info::CPU - Fetch machine CPU information
 
+=head1 VERSION
+
+version 0.07
+
+=head1 DESCRIPTION
+
 This info module fetches information about a machine's CPU using
 C</proc/meminfo>. It will not work on Solaris or Windows.
 
@@ -92,5 +108,17 @@ Runs all methods and returns their result in a unified hashref.
 
 =head1 AUTHOR
 
-Sawyer X, C<< <xsawyerx at cpan.org> >>
+  Sawyer X <xsawyerx@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Sawyer X.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
 
