@@ -1,4 +1,9 @@
+use strictures 1;
 package Data::Collector::Info::Memory;
+BEGIN {
+  $Data::Collector::Info::Memory::VERSION = '0.07';
+}
+# ABSTRACT: Fetch machine RAM information
 
 use Moose;
 use MooseX::StrictConstructor;
@@ -25,23 +30,33 @@ sub all {
 
 sub total {
     my $self = shift;
-    return $1 if $self->raw_data =~ /MemTotal\:\s+(\d+)\skB/;
+    my $raw  = $self->raw_data || q{};
+    return $1 if $raw =~ /MemTotal\:\s+(\d+)\skB/;
 }
 
 sub free {
     my $self = shift;
-    return $1 if $self->raw_data =~ /MemFree\:\s+(\d+)\skB/;
+    my $raw  = $self->raw_data || q{};
+    return $1 if $raw =~ /MemFree\:\s+(\d+)\skB/;
 }
 
 __PACKAGE__->meta->make_immutable;
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 Data::Collector::Info::Memory - Fetch machine RAM information
 
+=head1 VERSION
+
+version 0.07
+
+=head1 DESCRIPTION
+
 This info module fetches information about a machine's RAM status using
 C</proc/meminfo>. It will not work on Solaris or Windows.
 
@@ -71,5 +86,17 @@ Runs both methods and returns their result in a unified hashref.
 
 =head1 AUTHOR
 
-Sawyer X, C<< <xsawyerx at cpan.org> >>
+  Sawyer X <xsawyerx@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Sawyer X.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
 
