@@ -1,4 +1,9 @@
+use strictures 1;
 package Data::Collector::Serializer::SmartXML;
+BEGIN {
+  $Data::Collector::Serializer::SmartXML::VERSION = '0.07';
+}
+# ABSTRACT: A XML::Smart serializer for Data::Collector
 
 use Moose;
 use XML::Smart;
@@ -20,12 +25,19 @@ sub serialize {
 __PACKAGE__->meta->make_immutable;
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-Data::Collector::Serializer::SmartXML - A XML::Smart serializer for
-Data::Collector
+Data::Collector::Serializer::SmartXML - A XML::Smart serializer for Data::Collector
+
+=head1 VERSION
+
+version 0.07
+
+=head1 DESCRIPTION
 
 Utilizes L<XML::Smart>.
 
@@ -37,4 +49,17 @@ Gets data, serializes it and returns it.
 
 =head1 AUTHOR
 
-Sawyer X, C<< <xsawyerx at cpan.org> >>
+  Sawyer X <xsawyerx@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Sawyer X.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
